==> jc-1.4.0.tar.gz: scm/Car.c <==
// class scm.Car

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2c91b0ec714d8e44 scm_Car
// @dep_class e5a5e9dc399bf1a5 scm_Cell
// @dep_class 7cdfd1539eaf66a scm_Env
// @dep_class 43c5b3625f6dab19 scm_Obj
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_Exception
// @dep_header java_lang_String
// @dep_header scm_Car
// @dep_header scm_Cell
// @dep_header scm_Env
// @dep_header scm_Obj

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/Exception.h"
#include "java/lang/String.h"
#include "scm/Car.h"
#include "scm/Cell.h"
#include "scm/Env.h"
#include "scm/Obj.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_scm_Car$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_scm_Car$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_scm_Car$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_scm_Car$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_scm_Car$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_Car$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, _init$52f4ad9f2989aeee);

void
_jc_scm_Car$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_scm_Car$object *this)
{
	struct _jc_scm_Car$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(185);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// scm.Obj apply(scm.Cell, scm.Env) throws java.lang.Exception
//

static _jc_linenum _jc_scm_Car$linenum_table$apply$5e27fd10fb01c9e0[];

static const unsigned char _jc_scm_Car$param_ptypes$apply$5e27fd10fb01c9e0[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_scm_Car$exceptions$apply$5e27fd10fb01c9e0[] = {
	&_jc_java_lang_Exception$type
};

static _jc_type *const _jc_scm_Car$param_types$apply$5e27fd10fb01c9e0[] = {
	&_jc_scm_Cell$type,
	&_jc_scm_Env$type
};

_jc_method _jc_scm_Car$method_info$apply$5e27fd10fb01c9e0 = {
	.name=			"apply",
	.signature=		"(Lscm/Cell;Lscm/Env;)Lscm/Obj;",
	.class=			&_jc_scm_Car$type,
	.param_types=		&_jc_scm_Car$param_types$apply$5e27fd10fb01c9e0,
	.return_type=		&_jc_scm_Obj$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$apply$5e27fd10fb01c9e0,
	.signature_hash=	_JC_JLONG(0x5e27fd10fb01c9e0),
	.access_flags=		0,
	.function=		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_Car$vtable, scm_Car.apply$5e27fd10fb01c9e0) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	1,
	.exceptions=		&_jc_scm_Car$exceptions$apply$5e27fd10fb01c9e0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_scm_Car$linenum_table$apply$5e27fd10fb01c9e0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, apply$5e27fd10fb01c9e0);

_jc_object *
_jc_scm_Car$method$apply$5e27fd10fb01c9e0(_jc_env *const env, _jc_scm_Car$object *this, _jc_scm_Cell$object *param0, _jc_scm_Env$object *param1)
{
	struct _jc_scm_Car$object *r0;
	struct _jc_scm_Cell$object *r1;
	struct _jc_scm_Env$object *r2;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(190);				// 0
	r4 = _JC_REF_FIELD(env, r1, scm_Cell, car);
	r4 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x45e01bedb73fc9c4), _jc_object *, r2);
	r1 = _JC_CAST(env, &_jc_scm_Cell$type, r4);
	_JC_LINE_NUMBER(191);				// 1
	r4 = _JC_REF_FIELD(env, r1, scm_Cell, car);
	return r4;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_scm_Car$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_scm_Car$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_scm_Car$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_scm_Car$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_Car$vtable, scm_Car.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_Car$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_scm_Car$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_scm_Car$object *this)
{
	struct _jc_scm_Car$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(194);				// 0
	return _JC_STRING(env, "<#car#>");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_scm_Car$methods[] = {
	&_jc_scm_Car$method_info$_init$52f4ad9f2989aeee,
	&_jc_scm_Car$method_info$apply$5e27fd10fb01c9e0,
	&_jc_scm_Car$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_scm_Car$interfaces[] = {
	&_jc_scm_Obj$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_scm_Car$imethod_hash_bucket_68[] = {
	&_jc_scm_Procedure$method_info$eval$45e01bedb73fc9c4,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_scm_Car$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	_jc_scm_Car$imethod_hash_bucket_68
};

// Interface "quick" lookup hash table
static const void *_jc_scm_Car$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	&_jc_scm_Procedure$method$eval$45e01bedb73fc9c4
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_8[] = {
	&_jc_scm_Procedure$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_25[] = {
	&_jc_scm_Obj$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_68[] = {
	&_jc_scm_Car$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_scm_Car$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[8]=	_jc_scm_Car$instanceof_hash_bucket_8,
	[25]=	_jc_scm_Car$instanceof_hash_bucket_25,
	[68]=	_jc_scm_Car$instanceof_hash_bucket_68,
	[113]=	_jc_scm_Car$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_scm_Car$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "scm/Cell",	_JC_JLONG(0xe5a5e9dc399bf1a5) },
	{ "scm/Env",	_JC_JLONG(0x7cdfd1539eaf66a) },
	{ "scm/Obj",	_JC_JLONG(0x43c5b3625f6dab19) },
	{ "scm/Procedure",	_JC_JLONG(0x6d0a82a28dffac88) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_scm_Car$vtype _jc_scm_Car$type = {
    .type= {
	.name=			"scm/Car",
	.superclass=		&_jc_scm_Procedure$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_scm_Car$interfaces) / sizeof(*_jc_scm_Car$interfaces),
	.interfaces=		_jc_scm_Car$interfaces,
	.imethod_hash_table=	_jc_scm_Car$imethod_hash_table,
	.imethod_quick_table=	_jc_scm_Car$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0x2c91b0ec714d8e44),
		.source_file=		"Procedure.java",
		.instance_size=		sizeof(_jc_scm_Car$refs) + sizeof(_jc_scm_Car$object),
		.num_virtual_refs=	3,
		.num_methods=		sizeof(_jc_scm_Car$methods) / sizeof(*_jc_scm_Car$methods),
		.methods=		_jc_scm_Car$methods,
		.instanceof_hash_table=	_jc_scm_Car$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_scm_Car$class_depends) / sizeof(*_jc_scm_Car$class_depends),
		.class_depends=		_jc_scm_Car$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.scm_Procedure= {
	    .apply$5e27fd10fb01c9e0=			// overridden
		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	    .eval$45e01bedb73fc9c4=
		&_jc_scm_Procedure$method$eval$45e01bedb73fc9c4,
	    .extendargs$da3942a08c440de1=
		&_jc_scm_Procedure$method$extendargs$da3942a08c440de1,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	},
	.scm_Car= {
	    .apply$5e27fd10fb01c9e0=
		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	    .toString$7ea43b33b80a3070=
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: scm/Car.c <==
// class scm.Car

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 2c91b0ec714d8e44 scm_Car
// @dep_class e5a5e9dc399bf1a5 scm_Cell
// @dep_class 7cdfd1539eaf66a scm_Env
// @dep_class 43c5b3625f6dab19 scm_Obj
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_Exception
// @dep_header java_lang_String
// @dep_header scm_Car
// @dep_header scm_Cell
// @dep_header scm_Env
// @dep_header scm_Obj

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/Exception.h"
#include "java/lang/String.h"
#include "scm/Car.h"
#include "scm/Cell.h"
#include "scm/Env.h"
#include "scm/Obj.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_scm_Car$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_scm_Car$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_scm_Car$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_scm_Car$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_scm_Car$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_Car$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_scm_Car$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_scm_Car$object *this)
{
	struct _jc_scm_Car$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(185);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// scm.Obj apply(scm.Cell, scm.Env) throws java.lang.Exception
//

static _jc_linenum _jc_scm_Car$linenum_table$apply$5e27fd10fb01c9e0[];

static const unsigned char _jc_scm_Car$param_ptypes$apply$5e27fd10fb01c9e0[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_scm_Car$exceptions$apply$5e27fd10fb01c9e0[] = {
	&_jc_java_lang_Exception$type
};

static _jc_type *const _jc_scm_Car$param_types$apply$5e27fd10fb01c9e0[] = {
	&_jc_scm_Cell$type,
	&_jc_scm_Env$type
};

_jc_method _jc_scm_Car$method_info$apply$5e27fd10fb01c9e0 = {
	.name=			"apply",
	.signature=		"(Lscm/Cell;Lscm/Env;)Lscm/Obj;",
	.class=			&_jc_scm_Car$type,
	.param_types=		&_jc_scm_Car$param_types$apply$5e27fd10fb01c9e0,
	.return_type=		&_jc_scm_Obj$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$apply$5e27fd10fb01c9e0,
	.signature_hash=	_JC_JLONG(0x5e27fd10fb01c9e0),
	.access_flags=		0,
	.function=		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_Car$vtable, scm_Car.apply$5e27fd10fb01c9e0) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	1,
	.exceptions=		&_jc_scm_Car$exceptions$apply$5e27fd10fb01c9e0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_scm_Car$linenum_table$apply$5e27fd10fb01c9e0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, apply$5e27fd10fb01c9e0);

_jc_object * _JC_JCNI_ATTR
_jc_scm_Car$method$apply$5e27fd10fb01c9e0(_jc_env *const env, _jc_scm_Car$object *this, _jc_scm_Cell$object *param0, _jc_scm_Env$object *param1)
{
	struct _jc_scm_Car$object *r0;
	struct _jc_scm_Cell$object *r1;
	struct _jc_scm_Env$object *r2;
	struct _jc_object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(190);				// 0
	r4 = _JC_REF_FIELD(env, r1, scm_Cell, car);
	r4 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x45e01bedb73fc9c4), _jc_object *, (_jc_env *, struct _jc_object *, struct _jc_scm_Env$object *), r2);
	r1 = _JC_CAST(env, &_jc_scm_Cell$type, r4);
	_JC_LINE_NUMBER(191);				// 1
	r4 = _JC_REF_FIELD(env, r1, scm_Cell, car);
	return r4;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_scm_Car$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_scm_Car$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_scm_Car$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_scm_Car$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_scm_Car$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_Car$vtable, scm_Car.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_Car$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_Car, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_scm_Car$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_scm_Car$object *this)
{
	struct _jc_scm_Car$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(194);				// 0
	return _JC_STRING(env, "<#car#>");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_scm_Car$methods[] = {
	&_jc_scm_Car$method_info$_init$52f4ad9f2989aeee,
	&_jc_scm_Car$method_info$apply$5e27fd10fb01c9e0,
	&_jc_scm_Car$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_scm_Car$interfaces[] = {
	&_jc_scm_Obj$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_scm_Car$imethod_hash_bucket_68[] = {
	&_jc_scm_Procedure$method_info$eval$45e01bedb73fc9c4,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_scm_Car$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	_jc_scm_Car$imethod_hash_bucket_68
};

// Interface "quick" lookup hash table
static const void *_jc_scm_Car$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	&_jc_scm_Procedure$method$eval$45e01bedb73fc9c4
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_8[] = {
	&_jc_scm_Procedure$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_25[] = {
	&_jc_scm_Obj$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_68[] = {
	&_jc_scm_Car$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_Car$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_scm_Car$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[8]=	_jc_scm_Car$instanceof_hash_bucket_8,
	[25]=	_jc_scm_Car$instanceof_hash_bucket_25,
	[68]=	_jc_scm_Car$instanceof_hash_bucket_68,
	[101]=	_jc_scm_Car$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_scm_Car$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "scm/Cell",	_JC_JLONG(0xe5a5e9dc399bf1a5) },
	{ "scm/Env",	_JC_JLONG(0x7cdfd1539eaf66a) },
	{ "scm/Obj",	_JC_JLONG(0x43c5b3625f6dab19) },
	{ "scm/Procedure",	_JC_JLONG(0x6d0a82a28dffac88) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_scm_Car$vtype _jc_scm_Car$type = {
    .type= {
	.name=			"scm/Car",
	.superclass=		&_jc_scm_Procedure$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_scm_Car$interfaces) / sizeof(*_jc_scm_Car$interfaces),
	.interfaces=		_jc_scm_Car$interfaces,
	.imethod_hash_table=	_jc_scm_Car$imethod_hash_table,
	.imethod_quick_table=	_jc_scm_Car$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0x2c91b0ec714d8e44),
		.source_file=		"Procedure.java",
		.instance_size=		sizeof(_jc_scm_Car$refs) + sizeof(_jc_scm_Car$object),
		.num_virtual_refs=	3,
		.num_methods=		sizeof(_jc_scm_Car$methods) / sizeof(*_jc_scm_Car$methods),
		.methods=		_jc_scm_Car$methods,
		.instanceof_hash_table=	_jc_scm_Car$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_scm_Car$class_depends) / sizeof(*_jc_scm_Car$class_depends),
		.class_depends=		_jc_scm_Car$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.scm_Procedure= {
	    .apply$5e27fd10fb01c9e0=			// overridden
		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	    .eval$45e01bedb73fc9c4=
		&_jc_scm_Procedure$method$eval$45e01bedb73fc9c4,
	    .extendargs$da3942a08c440de1=
		&_jc_scm_Procedure$method$extendargs$da3942a08c440de1,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	},
	.scm_Car= {
	    .apply$5e27fd10fb01c9e0=
		&_jc_scm_Car$method$apply$5e27fd10fb01c9e0,
	    .toString$7ea43b33b80a3070=
		&_jc_scm_Car$method$toString$7ea43b33b80a3070,
	},
    }
};
